Learn R Programming

CopernicusMarine (version 0.4.9)

cms_get_client_info: Get Information About Copernicus Marine Clients

Description

[Stable] This function retrieves the client information from the Copernicus Marine Service. Among others, it lists where to find the catalogues required by this package

Usage

cms_get_client_info(...)

Value

In case of success it returns a named list with information about the available Copernicus Marine clients.

Arguments

...

Ignored

Author

Pepijn de Vries

See Also

Other supporting: cms_glossary(), cms_translate(), cms_write_ncdf()

Examples

Run this code
if (interactive()) {
  cms_get_client_info()
}

Run the code above in your browser using DataLab