- product
An identifier (type character) of the desired Copernicus marine product.
Can be obtained with cms_products_list.
- layer
The name of a desired layer within a product (type character). Can be obtained with cms_product_services (listed as id column).
- variable
The name of a desired variable in a specific layer of a product (type character).
Can be obtained with cms_product_details.
- region
Specification of the bounding box as a vector of numerics WGS84 lat and lon coordinates.
Should be in the order of: xmin, ymin, xmax, ymax.
- timerange
A vector with two elements (lower and upper value)
for a requested time range. The vector should be coercible to POSIXct.
- verticalrange
A vector with two elements (minimum and maximum)
numerical values for the depth of the vertical layers (if any). Note that values below the
sea surface needs to be specified as negative values.
- progress
A logical value. When TRUE (default) progress is reported to the console.
Otherwise, this function will silently proceed.
- crop
. This version now
uses the GDAL library to handle the subsetting and downloading of
subsets. The crop argument is therefore no longer supported.
- asset
Type of asset to be used when subsetting data. Should be one
of "default", "ARCO", "static", "omi", or "downsampled4".
When missing, set to NULL or set to "default", it will use the first
asset available for the requested product and layer, in the order as listed
before.
- ...
Ignored (reserved for future features).
- username
Your Copernicus marine user name. Can be provided with
cms_get_username() (default), or as argument here.
- password
Your Copernicus marine password. Can be provided as
cms_get_password() (default), or as argument here.