Function that returns a data.frame with a glossary of terminology
used by the Copernicus Marine Data Service. It is the same data.frame
that is used to render vignette("glossary").
Arguments
- search
Search terms to look for in the glossary
data.frame. Only rows that match these terms are returned. If missing, the entiredata.frameis returned.- match_fun
Function used to filter the
data.frame. It needs to be a function that uses apatternargument to match the text in thedata.frameagainst. It should return a vector oflogicalvalues or a vector ofintegerrow index values. By default it usesagrepl(), for a fuzzy match.- ...
Arguments passed to
match_fun.