cms_glossary: Get Copernicus Marine Terminology Glossary

View source: R/cms_glossary.R

cms_glossaryR Documentation

Get Copernicus Marine Terminology Glossary

Description

Function that returns a data.frame with a glossary of terminology used by the Copernicus Marine Data Service. It is the same data.frame that is used to render vignette("glossary").

Usage

cms_glossary(search, match_fun = agrep, ...)

Arguments

search

Search terms to look for in the glossary data.frame. Only rows that match these terms are returned. If missing, the entire data.frame is returned.

match_fun

Function used to filter the data.frame. It needs to be a function that uses a pattern argument to match the text in the data.frame against. It should return a vector of logical values or a vector of integer row index values. By default it uses agrepl(), for a fuzzy match.

...

Arguments passed to match_fun.

Value

Returns a data.frame with glossary info.

See Also

Other supporting: cms_get_client_info(), cms_translate()

Examples

cms_glossary("variable", ignore.case = TRUE)

CopernicusMarine documentation built on July 5, 2026, 5:06 p.m.