Learn R Programming

CopernicusMarine (version 0.4.9)

cms_glossary: Get Copernicus Marine Terminology Glossary

Description

[Stable] Function that returns a data.frame with a glossary of terminology used by the Copernicus Marine Data Service. It is the same data.frame that is used to render vignette("glossary").

Usage

cms_glossary(search, match_fun = agrep, ...)

Value

Returns a data.frame with glossary info.

Arguments

search

Search terms to look for in the glossary data.frame. Only rows that match these terms are returned. If missing, the entire data.frame is returned.

match_fun

Function used to filter the data.frame. It needs to be a function that uses a pattern argument to match the text in the data.frame against. It should return a vector of logical values or a vector of integer row index values. By default it uses agrepl(), for a fuzzy match.

...

Arguments passed to match_fun.

See Also

Other supporting: cms_get_client_info(), cms_translate(), cms_write_ncdf()

Examples

Run this code
cms_glossary("variable", ignore.case = TRUE)

Run the code above in your browser using DataLab