View source: R/cms_download_native.R
| cms_native_proxy | R Documentation |
The advantage of
stars_proxy objects,
is that they do not contain any data. They are therefore fast to handle
and consume only limited memory. You can still manipulate the object
lazily (like selecting slices). These operation are only executed when
calling stars::st_as_stars() or plot() on the object.
cms_native_proxy(
product,
layer,
pattern,
prefix,
variable,
...,
username = cms_get_username(),
password = cms_get_password()
)
product |
An identifier (type |
layer |
The name of a desired layer within a product (type |
pattern |
A regular expression (regex)
pattern. Only paths that match the pattern will be returned. It can be used
to select specific files. For instance if |
prefix |
A |
variable |
The variable name for which to create the |
... |
Ignored |
username |
Your Copernicus marine user name. Can be provided with
|
password |
Your Copernicus marine password. Can be provided as
|
For more details see vignette("proxy").
Pepijn de Vries
if (interactive()) {
native_proxy <-
cms_native_proxy(
product = "GLOBAL_ANALYSISFORECAST_PHY_001_024",
layer = "cmems_mod_glo_phy_anfc_0.083deg_PT1H-m",
prefix = "2022/06/",
pattern = "20220621"
)
plot(native_proxy["zos", 1:1000, 1:500, 1, 1], axes = TRUE)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.