Learn R Programming

CopernicusMarine (version 0.4.9)

cms_product_services: Obtain Available Services for a Specific Copernicus Marine Product

Description

[Stable] Obtain an overview of services provided by Copernicus for a specific marine product.

Usage

cms_product_services(product, ...)

Value

Returns a tibble with a list of available services for a Copernicus marine product.

Arguments

product

An identifier (type character) of the desired Copernicus marine product. Can be obtained with cms_products_list.

...

Ignored.

Author

Pepijn de Vries

Details

See vignette("product-info") for more details.

See Also

Other product: cms_cite_product(), cms_download_native(), cms_product_details(), cms_product_metadata(), cms_products_list()

Examples

Run this code
if (interactive()) {
  cms_product_services("GLOBAL_ANALYSISFORECAST_PHY_001_024")
}

Run the code above in your browser using DataLab