Learn R Programming

CopernicusMarine (version 0.4.9)

cms_products_list: List Products Available from <data.marine.copernicus.eu>

Description

[Stable] Collect a list of products and some brief descriptions for marine products available from Copernicus. cms_products_list() does not use a formal API, but provides a more detailed list. cms_products_list2() Does use the formal API, but provides less details.

Usage

cms_products_list(..., info_type = c("list", "meta"))

cms_products_list2(...)

Value

Returns a tibble of products available from https://data.marine.copernicus.eu or a named list when info_type = "meta". Returns NULL in case on-line services are unavailable.

Arguments

...

Allows you to pass (search) query parameters to apply to the list. When omitted, the full list of products is returned.

info_type

One of "list" (default) or "meta". "list" returns the actual list whereas "meta" returns meta information for the executed query (e.g. number of hits).

Author

Pepijn de Vries

Details

See vignette("product-info") for more details.

See Also

Other product: cms_cite_product(), cms_download_native(), cms_product_details(), cms_product_metadata(), cms_product_services()

Examples

Run this code
if (interactive()) {
  cms_products_list()

## Query a specific product:
  cms_products_list(freeText = "GLOBAL_ANALYSISFORECAST_PHY_001_024")
}

Run the code above in your browser using DataLab