View source: R/cms_download_subset.r
| cms_zarr_proxy | R Documentation |
The advantage of
stars_proxy objects,
is that they do not contain any data. They are therefore fast to handle
and consume only limited memory. You can still manipulate the object
lazily (like selecting slices). These operation are only executed when
calling stars::st_as_stars() or plot() on the object.
cms_zarr_proxy(
product,
layer,
variable,
asset,
...,
username = cms_get_username(),
password = cms_get_password()
)
product |
An identifier (type |
layer |
The name of a desired layer within a product (type |
variable |
The name of a desired variable in a specific layer of a product (type |
asset |
An asset that is available for the |
... |
Ignored (reserved for future features). |
username |
Your Copernicus marine user name. Can be provided with
|
password |
Your Copernicus marine password. Can be provided as
|
For more details see vignette("proxy").
Pepijn de Vries
if (interactive()) {
myproxy <- cms_zarr_proxy(
product = "GLOBAL_ANALYSISFORECAST_PHY_001_024",
layer = "cmems_mod_glo_phy-cur_anfc_0.083deg_P1D-m",
variable = c("uo", "vo"),
asset = "timeChunked")
plot(myproxy["uo",1:200,1:100,50,1], axes = TRUE)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.